Metrics

Korvet exposes metrics in Prometheus format via Spring Boot Actuator.

The metrics reference is organized by module:

See Tags and families for the tag vocabulary and top-level metric families.

Platform Metrics

Micrometer also exports standard JVM and system metrics.

Metric Description

jvm.memory.used

JVM memory used

jvm.memory.max

JVM maximum memory

jvm.gc.pause

Garbage collection pause time

jvm.threads.live

Live threads

process.cpu.usage

Process CPU usage

system.cpu.usage

System CPU usage

Next Steps